Index: lib/service/service.dart |
diff --git a/lib/service/service.dart b/lib/service/service.dart |
index 5a6def1189bf7be3a57b262cdb2c968aa86fb696..4cbab13dc3d8ed4699c94b51d9f9263b6191b337 100644 |
--- a/lib/service/service.dart |
+++ b/lib/service/service.dart |
@@ -2,16 +2,16 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
// The dart:fletch.service library is a low-level communication library that |
// allows dart code to register services that are accessible through |
// the C API. |
-library dart.fletch.service; |
+library dart.dartino.service; |
-import 'dart:fletch._system' as fletch; |
-import 'dart:fletch'; |
+import 'dart:dartino._system' as dartino; |
+import 'dart:dartino'; |
// TODO(ajohnsen): Rename file. |
-@fletch.native void register(String service, Port servicePort) { |
+@dartino.native void register(String service, Port servicePort) { |
throw new UnsupportedError("Was not able to register service '$service'"); |
} |
@@ -2,16 +2,16 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-// The dart:fletch.service library is a low-level communication library that |
+// The dart:dartino.service library is a low-level communication library that |
// allows dart code to register services that are accessible through |
// the C API. |